geowatch.cli.queue\_cli.prepare\_ta2\_dataset module
====================================================

.. automodule:: geowatch.cli.queue_cli.prepare_ta2_dataset
   :members:
   :undoc-members:
   :show-inheritance:
